@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::Network;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 # Dependencies
 
@@ -70,20 +70,6 @@ sub read {
     return $data;
 }
 
-
-sub print {
-    my ( $self, $raw ) = @_;
-    my @chunks;
-    my $buffer = $self->_buffer;
-    my $n      = 64;               # Size of each chunk in bytes
-
-    @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
-    for my $chunk (@chunks) {
-        $self->_connection->write($chunk);
-    }
-    $self->_buffer('');
-}
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -99,7 +85,7 @@ Printer::ESCPOS::Connections::Network - Network Connection Interface for Printer
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 ATTRIBUTES
 
@@ -117,10 +103,6 @@ Contains the network port of the device when its a network printer. The module c
 
 Read Data from the printer 
 
-=head2 print
-
-Sends buffer data to the printer.
-
 =head1 AUTHOR
 
 Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
