@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::Serial;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 # Dependencies
 
@@ -86,8 +86,17 @@ sub read {
 sub print {
     my ( $self, $raw ) = @_;
     my @chunks;
+
     my $buffer = $self->_buffer;
-    my $n      = 8;                # Size of each chunk in bytes
+    if ( defined $raw ) {
+        $buffer = $raw;
+    }
+    else {
+        $buffer = $self->_buffer;
+        $self->_buffer('');
+    }
+
+    my $n = 8;    # Size of each chunk in bytes
     $n = 64 if ( $self->serialOverUSB );
 
     @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
@@ -101,7 +110,6 @@ sub print {
               ; # Serial Port is annoying, it doesn't tell you when it is ready to get the next chunk
         }
     }
-    $self->_buffer('');
 }
 
 no Moose;
@@ -119,7 +127,7 @@ Printer::ESCPOS::Connections::Serial - Serial Connection Interface for Printer::
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 ATTRIBUTES
 
